@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 from mesures.dates import *
-from mesures.headers import A5D_HEADER as columns
+from mesures.headers import A5D_HEADER as COLUMNS
 from mesures.parsers.dummy_data import DummyCurve
+from mesures.utils import check_line_terminator_param
 import os
 import pandas as pd
 
 
-class A5D():
+class A5D(object):
     def __init__(self, data, distributor=None, comer=None, compression='bz2', version=0):
         """
         :param data: list of dicts or absolute file_path
@@ -16,6 +17,7 @@ class A5D():
         """
         if isinstance(data, list):
             data = DummyCurve(data).curve_data
+        self.columns = COLUMNS
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'A5D'
@@ -64,10 +66,6 @@ class A5D():
     def ai(self):
         return int(self.file['ai'].sum())
 
-    @property
-    def ae(self):
-        return int(self.file['ae'].sum())
-
     @property
     def cups(self):
         return list(set(self.file['cups']))
@@ -79,7 +77,7 @@ class A5D():
     def reader(self, filepath):
         if isinstance(filepath, str):
             df = pd.read_csv(
-                filepath, sep=';', names=columns
+                filepath, sep=';', names=self.columns
             )
         elif isinstance(filepath, list):
             df = pd.DataFrame(data=filepath)
@@ -87,12 +85,13 @@ class A5D():
             raise Exception("Filepath must be an str or a list")
 
         df = df.groupby(['cups', 'timestamp', 'season', 'factura']).aggregate(
-            {'ai': 'sum', 'ae': 'sum'}
+            {'ai': 'sum', 'ae': 'sum',
+             'r1': 'sum', 'r2': 'sum', 'r3': 'sum', 'r4': 'sum'}
         ).reset_index()
         df['timestamp'] = df['timestamp'].apply(lambda x: x.strftime('%Y/%m/%d %H:%M'))
         for key in ['r1', 'r2', 'r3', 'r4', 'ae', 'method', 'firmeza']:
             df[key] = ''
-        df = df[columns]
+        df = df[self.columns]
         return df
 
     def writer(self):
@@ -100,17 +99,21 @@ class A5D():
         A5D contains a hourly raw curve
         :return: file path
         """
-        file_path = os.path.join('/tmp', self.filename)
+        existing_files = os.listdir('/tmp')
+        if existing_files:
+            versions = [int(f.split('.')[1]) for f in existing_files if self.filename.split('.')[0] in f]
+            if versions:
+                self.version = max(versions) + 1
 
+        file_path = os.path.join('/tmp', self.filename)
         kwargs = {'sep': ';',
                   'header': False,
-                  'columns': columns,
+                  'columns': self.columns,
                   'index': False,
-                  'line_terminator': ';\n'
+                  check_line_terminator_param(): ';\n'
                   }
         if self.default_compression:
             kwargs.update({'compression': self.default_compression})
 
         self.file.to_csv(file_path, **kwargs)
-
         return file_path
