@@ -2,6 +2,7 @@
 from mesures.dates import *
 from mesures.headers import AGRECL_HEADER as columns
 from mesures.parsers.dummy_data import DummyKeys
+from mesures.utils import check_line_terminator_param
 import os
 import pandas as pd
 
@@ -67,7 +68,7 @@ class AGRECL(object):
         df['data_alta'] = df['data_alta'].apply(lambda x: x.strftime('%Y/%m/%d %H'))
         df['data_baixa'] = df['data_baixa'].apply(
             lambda x: '' if not isinstance(x, pd.Timestamp) else x.strftime('%Y/%m/%d %H'))
-        df = df.sort_values(['origen', 'comercialitzadora'])
+        df = df.sort_values(by=['origen', 'comercialitzadora'], ascending=[False, True])
         df = df[columns]
         return df
 
@@ -80,7 +81,7 @@ class AGRECL(object):
                   'header': False,
                   'columns': columns,
                   'index': False,
-                  'line_terminator': ';\n'
+                  check_line_terminator_param(): ';\n'
                   }
         if self.default_compression:
             kwargs.update({'compression': self.default_compression})
