@@ -2,6 +2,7 @@
 from mesures.dates import *
 from mesures.headers import CUPSCAU_HEADER as columns
 from mesures.parsers.dummy_data import DummyKeys
+from mesures.utils import check_line_terminator_param
 import os
 import numpy as np
 import pandas as pd
@@ -91,7 +92,7 @@ class CUPSCAU(object):
                   'header': False,
                   'columns': columns,
                   'index': False,
-                  'line_terminator': ';\n'
+                  check_line_terminator_param(): ';\n'
                   }
         if self.default_compression:
             kwargs.update({'compression': self.default_compression})
