@@ -7,3 +7,6 @@ DATETIME_MASK = '%Y/%m/%d %H:%M:%S'
 REE_END_DATE = '30000101'
 REE_END_DATE_HOUR = '3000/01/01 01'
 SIMPLE_DATE_MASK = '%Y%m%d'
+
+# Since v41 of SIMEL specifications
+CUPSDAT_CPUS45_REE_END_DATE_HOUR = '3000/01/01 00'
\ No newline at end of file
