@@ -2,13 +2,14 @@
 from mesures.dates import *
 from mesures.headers import F1_HEADER as COLUMNS
 from mesures.parsers.dummy_data import DummyCurve
+from mesures.utils import check_line_terminator_param
 from zipfile import ZipFile
 import os
 import pandas as pd
 
 
 class F1(object):
-    def __init__(self, data, distributor=None, compression='bz2', version=0):
+    def __init__(self, data, distributor=None, compression='bz2', allow_decimals=False, version=0):
         """
         :param data: list of dicts or absolute file_path
         :param distributor: str distributor REE code
@@ -17,6 +18,7 @@ class F1(object):
         if isinstance(data, list):
             data = DummyCurve(data).curve_data
         self.columns = COLUMNS
+        self.allow_decimals = allow_decimals
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'F1'
@@ -55,9 +57,9 @@ class F1(object):
 
     @property
     def zip_filename(self):
-        return "{prefix}_{distributor}_{measures_date}_{timestamp}.zip".format(
+        return "{prefix}_{distributor}_{measures_date}_{timestamp}.{version}.zip".format(
             prefix=self.prefix, distributor=self.distributor, measures_date=self.measures_date[:10].replace('/', ''),
-            timestamp=self.generation_date.strftime('%Y%m%d')
+            timestamp=self.generation_date.strftime('%Y%m%d'), version=self.version
         )
 
     @property
@@ -128,6 +130,11 @@ class F1(object):
 
         df['res'] = 0
         df['res2'] = 0
+
+        if not self.allow_decimals:
+            for key in ['ai', 'ae', 'r1', 'r2', 'r3', 'r4']:
+                df[key] = df[key].astype('int')
+
         df = df[self.columns]
         return df
 
@@ -139,25 +146,42 @@ class F1(object):
         daymin = self.file['timestamp'].min()
         daymax = self.file['timestamp'].max()
         self.measures_date = daymin
+
+        existing_files = os.listdir('/tmp')
+        if existing_files:
+            zip_versions = [int(f.split('.')[1]) for f in existing_files if self.zip_filename.split('.')[0] in f and '.zip' in f]
+            if zip_versions:
+                self.version = max(zip_versions) + 1
+
+        zip_measures_date = self.measures_date
+        zip_version = self.version
         zipped_file = ZipFile(os.path.join('/tmp', self.zip_filename), 'w')
         while daymin <= daymax:
             di = daymin
             df = (datetime.strptime(daymin, DATETIME_MASK) + timedelta(days=1)).strftime(DATETIME_MASK)
             self.measures_date = di
             dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
-            # dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime('%Y/%m/%d %H:%M'))
-            file_path = os.path.join('/tmp', self.filename)
-            kwargs = {'sep': ';',
-                      'header': False,
-                      'columns': self.columns,
-                      'index': False,
-                      'line_terminator': ';\n'
-                      }
-            if self.default_compression:
-                kwargs.update({'compression': self.default_compression})
+            # Avoid to generate file if dataframe is empty
+            if len(dataf):
+                existing_files = os.listdir('/tmp')
+                if existing_files:
+                    versions = [int(f.split('.')[1]) for f in existing_files if self.filename.split('.')[0] in f and '.zip' not in f]
+                    if versions:
+                        self.version = max(versions) + 1
+                file_path = os.path.join('/tmp', self.filename)
+                kwargs = {'sep': ';',
+                          'header': False,
+                          'columns': self.columns,
+                          'index': False,
+                          check_line_terminator_param(): ';\n'
+                          }
+                if self.default_compression:
+                    kwargs.update({'compression': self.default_compression})
+                dataf.to_csv(file_path, **kwargs)
+                zipped_file.write(file_path, arcname=os.path.basename(file_path))
 
-            dataf.to_csv(file_path, **kwargs)
             daymin = df
-            zipped_file.write(file_path, arcname=os.path.basename(file_path))
         zipped_file.close()
+        self.measures_date = zip_measures_date
+        self.version = zip_version
         return zipped_file.filename
