@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# Valid for A5D and B5D
 A5D_HEADER = [
     'cups',
     'timestamp',
@@ -53,22 +54,8 @@ AUTOCONSUMO_HEADER = [
     'subgrup',
     'emmagatzematge',
     'data_alta',
-    'data_baixa'
-]
-
-B5D_HEADER = [
-    'cups',
-    'timestamp',
-    'season',
-    'ai',
-    'ae',
-    'r1',
-    'r2',
-    'r3',
-    'r4',
-    'method',
-    'firmeza',
-    'factura'
+    'data_baixa',
+    'estat'
 ]
 
 CILCAU_HEADER = [
@@ -206,6 +193,10 @@ CUPSDAT_HEADER = [
     'tension'                       # str(2)
 ]
 
+CUPSDAT_HEADER_2024 = CUPSDAT_HEADER + [
+    'indicador_envio_medida'        # str(1) in ('Q', 'H')
+]
+
 CUPSELECTRO_HEADER = [
     'cups',                     # str(22)
     'cif_empresa',              # str(9)
@@ -313,6 +304,30 @@ F5D_HEADER = F5_HEADER + [
     'factura'       # str
 ]
 
+MAGCL_HEADER = [
+    'distribuidora',        # str(4)
+    'comercialitzadora',    # str(4)
+    'agree_tensio',         # str(2)
+    'agree_tarifa',         # str(2)
+    'agree_dh',             # str(2)
+    'agree_tipo',           # str(2)
+    'provincia',            # str(2)
+    'tipus_demanda',        # str(2)
+    'timestamp',            # str(aaaa/mm/dd hh:mm)
+    'estacio',              # str(1) in ('0' for winter, '1' for summer)
+    'magnitud',             # str(2)
+    'consum',               # int(10)
+    'n_punts',              # int(7)
+    'm_iec_real',           # int(10)
+    'n_iec_real',           # int(7)
+    'm_iec_estimada',       # int(10)
+    'n_iec_estimada',       # int(7)
+    'm_integrats_real',     # int(10)
+    'n_integrats_real',     # int(7)
+    'm_integrats_estimada', # int(10)
+    'n_integrats_estimada'  # int(7)
+]
+
 MCIL345_HEADER = [
     'cil',                  # str(25) CUPS + 3 digits ('001' style)
     'timestamp',            # str(aaaa/mm/dd hh)
@@ -338,6 +353,49 @@ MEDIDAS_HEADER = [
     'read_type'             # str(1) in ('E' for estimated, 'R' for real)
 ]
 
+OBAGRECL_HEADER = [
+    'distribuidora',        # str(4)
+    'comercialitzadora',    # str(4)
+    'agree_tensio',         # str(2)
+    'agree_tarifa',         # str(2)
+    'agree_dh',             # str(2)
+    'agree_tipo',           # str(2)
+    'provincia',            # str(2)
+    'tipus_demanda',        # str(3)
+    'periode',              # str aaaa/mm
+    'motiu_emissor',        # str(3)
+    'magnitud',             # str(2) AE/AS
+    'energia_publicada',    # str(10) kWh
+    'energia_proposada',    # str(10) kWh
+    'comentari_emissor',    # str(255)
+    'auto_obj'              # str(1) S/N
+]
+
+OBCIL_HEADER = [
+    'cil',                  # str(25)
+    'periode',              # str aaaa/mm
+    'motiu_emissor',        # str(3)
+    'ae_publicada',         # str(10) kWh
+    'ae_proposada',         # str(10) kWh
+    'r2_publicada',         # str(10) kVArh
+    'r2_proposada',         # str(10) kVArh
+    'r3_publicada',         # str(10) kVArh
+    'r3_proposada',         # str(10) kVArh
+    'comentari_emissor',    # str(255)
+    'auto_obj'              # str(1) S/N
+]
+
+OBCUPS_HEADER = [
+    'cups',                 # str(22)
+    'periode',              # str aaaa/mm
+    'motiu_emissor',        # str(3)
+    'energia_publicada',    # str(10) kWh
+    'energia_proposada',    # str(10) kWh
+    'comentari_emissor',    # str(255)
+    'auto_obj',             # str(1) S/N
+    'magnitud'              # str(2) AS/AE
+]
+
 P1_HEADER = [
     'cups',          # str(22)
     'tipo_medida',   # str(2) (always '11')
@@ -477,3 +535,74 @@ POTELECTRO_HEADER = [
     'energia_proyectada_p5',    # int(10)
     'energia_proyectada_p6'     # int(10)
 ]
+
+REOBJEAGRECL_HEADER = [
+    'distribuidora',        # str(4)
+    'comercialitzadora',    # str(4)
+    'agree_tensio',         # str(2)
+    'agree_tarifa',         # str(2)
+    'agree_dh',             # str(2)
+    'agree_tipo',           # str(2)
+    'provincia',            # str(2)
+    'tipus_demanda',        # str(2)
+    'data_inici',           # str aaaa/mm/dd hh
+    'data_fi',              # str aaaa/mm/dd hh
+    'motiu_emissor',        # str(3)
+    'magnitud',             # str(3)
+    'energia_publicada',    # str(10) kWh
+    'energia_proposada',    # str(10) kWh
+    'comentari_emissor',    # str(255)
+    'auto_obj',             # str(1) S/N
+    'acceptacio',           # str(1) S/N
+    'motiu_receptor',       # str(1)
+    'comentari_receptor'    # str(255)
+]
+
+REOBJEINCL_HEADER = [
+    'cups',                         # str(22)
+    'data_inici',                   # str aaaammdd hh
+    'data_fi',                      # str aaaammdd hh
+    'motiu_emissor',                # str(3)
+    'energia_entrant_publicada',    # str(10) kWh
+    'energia_entrant_proposada',    # str(10) kWh
+    'energia_sortint_publicada',    # str(10) kWh
+    'energia_sortint_proposada',    # str(10) kWh
+    'comentari_emissor',            # str(255)
+    'auto_obj',                     # str(1) S/N
+    'acceptacio',                   # str(1) S/N
+    'motiu_receptor',               # str(2)
+    'comentari_receptor'            # str(255)
+]
+
+REOBJE2_HEADER = [
+    'cups',                         # str(22)
+    'data_inici',                   # str aaaammdd hh
+    'data_fi',                      # str aaaammdd hh
+    'motiu_emissor',                # str(3)
+    'energia_publicada',            # str(10) kWh
+    'energia_proposada',            # str(10) kWh
+    'comentari_emissor',            # str(255)
+    'auto_obj',                     # str(1) S/N
+    'acceptacio',                   # str(1) S/N
+    'motiu_receptor',               # str(2)
+    'comentari_receptor',           # str(255)
+    'magnitud'                      # str(2) AS/AE
+]
+
+REOBJECIL_HEADER = [
+    'cil',                          # str(22)
+    'data_inici',                   # str aaaammdd hh
+    'data_fi',                      # str aaaammdd hh
+    'motiu_emissor',                # str(3)
+    'as_publicada',                 # str(10) kWh
+    'as_proposada',                 # str(10) kWh
+    'r2_publicada',                 # str(10) kVArh
+    'r2_proposada',                 # str(10) kVArh
+    'r3_publicada',                 # str(10) kVArh
+    'r3_proposada',                 # str(10) kVArh
+    'comentari_emissor',            # str(255)
+    'auto_obj',                     # str(1) S/N
+    'acceptacio',                   # str(1) S/N
+    'motiu_receptor',               # str(2)
+    'comentari_receptor'            # str(255)
+]
\ No newline at end of file
