@@ -2,6 +2,7 @@
 from mesures.dates import *
 from mesures.headers import P1_HEADER as COLUMNS
 from mesures.parsers.dummy_data import DummyCurve
+from mesures.utils import check_line_terminator_param
 from zipfile import ZipFile
 import os
 import pandas as pd
@@ -23,6 +24,7 @@ class P1(object):
         self.version = version
         self.distributor = distributor
         self.default_compression = compression
+        self.measures_date = None
 
     def __repr__(self):
         return "{}: {} kWh".format(self.filename, self.total)
@@ -56,10 +58,11 @@ class P1(object):
 
     @property
     def zip_filename(self):
-        return "{prefix}_{distributor}_{measures_date}_{timestamp}.zip".format(
+        return "{prefix}_{distributor}_{measures_date}_{timestamp}.{version}.zip".format(
             prefix=self.prefix, distributor=self.distributor,
             measures_date=self.measures_date[:10].replace('/', ''),
-            timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK)
+            timestamp=self.generation_date.strftime(SIMPLE_DATE_MASK),
+            version=self.version
         )
 
     @property
@@ -107,7 +110,16 @@ class P1(object):
             raise Exception("Filepath must be an str or a list")
 
         df['tipo_medida'] = 11
-        df.groupby(['cups', 'tipo_medida', 'timestamp', 'season', 'method']).aggregate({'ai': 'sum'})
+        df.groupby(
+            ['cups', 'tipo_medida', 'timestamp', 'season', 'method']
+        ).aggregate(
+            {'ai': 'sum',
+             'ae': 'sum',
+             'r1': 'sum',
+             'r2': 'sum',
+             'r3': 'sum',
+             'r4': 'sum'}
+        )
 
         df['timestamp'] = df['timestamp'].apply(lambda x: x.strftime(DATETIME_MASK))
 
@@ -130,25 +142,45 @@ class P1(object):
         daymin = self.file['timestamp'].min()
         daymax = self.file['timestamp'].max()
         self.measures_date = daymin
+        existing_files = os.listdir('/tmp')
+        if existing_files:
+            zip_versions = [int(f.split('.')[1]) for f in existing_files if self.zip_filename.split('.')[0] in f and '.zip' in f]
+            if zip_versions:
+                self.version = max(zip_versions) + 1
+
+        zip_measures_date = self.measures_date
+        zip_version = self.version
         zipped_file = ZipFile(os.path.join('/tmp', self.zip_filename), 'w')
         while daymin <= daymax:
             di = daymin
             df = (datetime.strptime(daymin, DATETIME_MASK) + timedelta(days=1)).strftime(DATETIME_MASK)
             self.measures_date = di
             dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
-            # dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime(DATETIME_HOUR_MASK))
-            file_path = os.path.join('/tmp', self.filename)
-            kwargs = {'sep': ';',
-                      'header': False,
-                      'columns': self.columns,
-                      'index': False,
-                      'line_terminator': ';\n'
-                      }
-            if self.default_compression:
-                kwargs.update({'compression': self.default_compression})
+            if len(dataf):
+                existing_files = os.listdir('/tmp')
+                if existing_files:
+                    versions = [int(f.split('.')[1]) for f in existing_files if self.filename.split('.')[0] in f and '.zip' not in f]
+                    if versions:
+                        self.version = max(versions) + 1
+                # dataf['timestamp'] = dataf['timestamp'].apply(lambda x: x.strftime(DATETIME_HOUR_MASK))
+                file_path = os.path.join('/tmp', self.filename)
+                kwargs = {'sep': ';',
+                          'header': False,
+                          'columns': self.columns,
+                          'index': False,
+                          check_line_terminator_param(): ';\n'
+                          }
+                if self.default_compression:
+                    kwargs.update({'compression': self.default_compression})
+
+                dataf.to_csv(file_path, **kwargs)
+                zipped_file.write(file_path, arcname=os.path.basename(file_path))
 
-            dataf.to_csv(file_path, **kwargs)
             daymin = df
-            zipped_file.write(file_path, arcname=os.path.basename(file_path))
         zipped_file.close()
+        self.measures_date = zip_measures_date
+        self.version = zip_version
+        new_zip_filename = os.path.join('/tmp', self.zip_filename)
+        os.rename(zipped_file.filename, new_zip_filename)
+        zipped_file.filename = new_zip_filename
         return zipped_file.filename
