@@ -42,9 +42,12 @@ class DummyCurve(object):
                 except ValueError:
                     # str season
                     data['season'] = 0 if data['season'].lower() == 'w' else 1
-            if 'kind_fact' in data:
+            if 'kind_fact' in data and not 'method' in data:
                 try:
                     data['method'] = int(data.pop('kind_fact'))
+                    # 0 is not a valid method
+                    if data['method'] < 1:
+                        data['method'] = 1
                 except ValueError:
                     data['method'] = 1
             if 'firm_fact' in data:
