@@ -2,6 +2,7 @@
 from mesures.dates import *
 from mesures.headers import PMEST_HEADER as columns
 from mesures.parsers.dummy_data import DummyCurve
+from mesures.utils import check_line_terminator_param
 from zipfile import ZipFile
 import os
 import pandas as pd
@@ -16,6 +17,7 @@ class PMEST(object):
         """
         if isinstance(data, list):
             data = DummyCurve(data).curve_data
+        self.columns = columns
         self.file = self.reader(data)
         self.generation_date = datetime.now()
         self.prefix = 'PMEST'
@@ -92,7 +94,7 @@ class PMEST(object):
     def reader(self, filepath):
         if isinstance(filepath, str):
             df = pd.read_csv(
-                filepath, sep=';', names=columns
+                filepath, sep=';', names=self.columns
             )
         elif isinstance(filepath, list):
             df = pd.DataFrame(data=filepath)
@@ -119,7 +121,7 @@ class PMEST(object):
                 'r4': 'sum',
             }
         ).reset_index()
-        df = df[columns]
+        df = df[self.columns]
         return df
 
     def writer(self):
@@ -137,12 +139,13 @@ class PMEST(object):
             self.measures_date = di
             dataf = self.file[(self.file['timestamp'] >= di) & (self.file['timestamp'] < df)]
             dataf['timestamp'] = dataf.apply(lambda row: row['timestamp'].strftime('%Y/%m/%d %H'), axis=1)
+            dataf['timestamp'] = dataf['timestamp'].astype(str)
             file_path = os.path.join('/tmp', self.filename)
             kwargs = {'sep': ';',
                       'header': False,
-                      'columns': columns,
+                      'columns': self.columns,
                       'index': False,
-                      'line_terminator': ';\n'
+                      check_line_terminator_param(): ';\n'
                       }
             if self.default_compression:
                 kwargs.update({'compression': self.default_compression})
